// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
var app = angular.module('starter', ['ionic', 'ionic-material']);

app.run(function ($ionicPlatform, $state, $timeout) {
    $ionicPlatform.ready(function () {
        // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
        // for form inputs)

        if (window.cordova && window.cordova.plugins.Keyboard) {
            cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
        }
        if (window.StatusBar) {
            StatusBar.styleDefault();
        }

        backbutton = 0;
    });

    // Disable BACK button on home
    $ionicPlatform.registerBackButtonAction(function (event) {
        if ($state.current.name == "app.main") {
            if (backbutton == 0) {
                backbutton++;
                navigator.vibrate(300);
                window.plugins.toast.showShortBottom('Presione de nuevo para salir');
                $timeout(function () {
                    backbutton = 0;
                }, 2000);
            } else {
                navigator.app.exitApp();
            }
        }
        else {
            backbutton = 0;
            navigator.app.backHistory();
        }
    }, 100);

});

app.config(function ($stateProvider, $urlRouterProvider) {
    $stateProvider

        .state('app', {
            url: '/app',
            abstract: true,
            templateUrl: 'templates/menu.html',
            controller: 'AppCtrl'
        })

        .state('app.main', {
            url: '/main',
            views: {
                'menuContent': {
                    templateUrl: 'templates/main.html',
                    controller: 'MainCtrl'
                }
            }
        })
        
        .state('app.products', {
            url: '/products/:cat',
            views: {
                'menuContent': {
                    templateUrl: 'templates/products.html',
                    controller: 'ProductsCtrl'
                }
            }
        })

        .state('app.product', {
            url: '/product/:cat/:id',
            views: {
                'menuContent': {
                    templateUrl: 'templates/product.html',
                    controller: 'ProductCtrl'
                }
            }
        })

        .state('app.services', {
            url: '/services',
            views: {
                'menuContent': {
                    templateUrl: 'templates/services.html',
                    controller: 'ServicesCtrl'
                }
            }
        })

        .state('app.contact', {
            url: '/contact',
            views: {
                'menuContent': {
                    templateUrl: 'templates/contact.html',
                    controller: 'ContactCtrl'
                }
            }
        })

        .state('app.update', {
            url: '/update',
            views: {
                'menuContent': {
                    templateUrl: 'templates/update.html',
                    controller: 'UpdateCtrl'
                }
            }
        })

    ;
    $urlRouterProvider.otherwise('/app/main');
});


app.controller('AppCtrl', function () {
    modal = false;
});

app.controller('ContactCtrl',
    ['$scope', '$http',
        function ($scope, $http) {

            $http.get('data/config.json')
                .success(function (data) {
                    $scope.config = data.config;
                });
        }]);

app.controller('UpdateCtrl',
    ['$scope', '$http',
        function ($scope, $http) {

            $http.get('data/config.json')
                .success(function (data) {
                    $scope.config = data.config;
                });
        }]);

app.controller('ServicesCtrl',
    ['$scope', '$http',
        function ($scope, $http) {

            $http.get('data/config.json')
                .success(function (data) {
                    $scope.config = data.config;
                    $scope.servicios = data.servicios;
                });

        }]);

app.controller('ProductsCtrl',
    ['$scope', '$http', '$state',
        function ($scope, $http, $state) {

            $http.get('data/vendedores.json').success(function (data) {
                $scope.vendedores = data.vendedores;
                
                $scope.cat = $state.params.cat;
                
                $http.get('data/' + $scope.cat + '.json').success(function (data) {
                    $scope.productos = data.productos;
                });
            });


        }]);

app.controller('ProductCtrl',
    ['$scope', '$http', '$state', '$ionicSlideBoxDelegate',
        function ($scope, $http, $state, $ionicSlideBoxDelegate) {

            $scope.cat = $state.params.cat;
            
            $http.get('data/' + $scope.cat + '.json')
                .success(function (data) {
                    $scope.producto = data.productos[$state.params.id];

                    $http.get('data/vendedores.json').success(function (data) {
                        $scope.vendedor = data.vendedores[$scope.producto.vendedor];
                    });

                    $scope.slideHasChanged();
                });

            $scope.slideHasChanged = function () {
                $ionicSlideBoxDelegate.update();
            };

        }]);

app.controller('MainCtrl',
    ['$scope', '$http', '$state',
        function ($scope, $http, $state) {

            
        }]);

